package it.danieleverducci.subitobeers.networking

import android.util.Log
import java.util.*

class BeersFilter {
    // The date format is like "09/2007" (MM/YYYY). Month start from 1.
    var brewedBefore: String? = null
    var brewedAfter: String? = null

    val brewedBeforeYear: Int
            get() = getYear(brewedBefore)
    val brewedAfterYear: Int
            get() = getYear(brewedAfter)
    val brewedBeforeMonth: Int
            get() = getMonth(brewedBefore)
    val brewedAfterMonth: Int
            get() = getMonth(brewedAfter)

    fun clear() {
        brewedBefore = null
        brewedAfter = null
    }

    /**
     * Sets the end filter date.
     * Uses Calendar month format (January is 0, December is 11).
     * @param month Month starting from 0
     * @param year Year as 4-digit
     */
    fun setBrewedBefore(month: Int, year: Int) {
        brewedBefore = "${String.format("%02d", month + 1)}-${String.format("%04d", year)}"
    }

    /**
     * Sets the start filter date.
     * Uses Calendar month format (January is 0, December is 11).
     * @param month Month starting from 0
     * @param year Year as 4-digit
     */
    fun setBrewedAfter(month: Int, year: Int) {
        brewedAfter = "${String.format("%02d", month + 1)}-${String.format("%04d", year)}"
    }

    /**
     * Returns the selected year, if any, otherwise returns current year
     * @param filter value String?
     * @return the selected year
     */
    private fun getYear(value: String?): Int {
        if (value == null) return Calendar.getInstance().get(Calendar.YEAR)
        return value.substring(3).toInt()
    }

    /**
     * Returns the selected month, if any, otherwise returns current month
     * Uses Calendar month format (January is 0, December is 11)
     * @param filter value String?
     * @return the selected month
     */
    private fun getMonth(value: String?): Int {
        if (value == null) return Calendar.getInstance().get(Calendar.MONTH)
        return value.substring(0,2).toInt()
    }
}